import 'package:flextech/utils/deouncer.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class SearchAppBar extends StatefulWidget implements PreferredSizeWidget {
  final Color? color;

  @override
  Size get preferredSize => const Size.fromHeight(56.0);

  final Function search;

  const SearchAppBar({
    Key? key,
    required this.search,
    this.color,
  }) : super(key: key);

  @override
  _SearchAppBarState createState() => _SearchAppBarState();
}

class _SearchAppBarState extends State<SearchAppBar> {
  TextEditingController _searchController = TextEditingController();
  final Debouncer _onSearchDebouncer =
      Debouncer(delay: new Duration(milliseconds: 500));

  @override
  Widget build(BuildContext context) {
    var _color = (widget.color != null ? widget.color! : Colors.white);

    return SliverAppBar(
      snap: true,
      pinned: true,
      floating: true,
      toolbarHeight: 100,
      backgroundColor: Colors.black54,
      flexibleSpace: FlexibleSpaceBar(
        centerTitle: true,
        title: Padding(
          padding: const EdgeInsets.all(8.0),
          child: TextField(
            controller: _searchController,
            onChanged: (value) {
              _onSearchDebouncer.debounce(() {
                this.widget.search(_searchController.text);
              });
            },
            onSubmitted: (value) {
              this.widget.search(_searchController.text);
            },
            style: TextStyle(color: _color),
            cursorColor: _color,
            decoration: InputDecoration(
              border: OutlineInputBorder(
                borderRadius: BorderRadius.all(Radius.circular(4.0)),
                borderSide: BorderSide(width: 1.0),
              ),
              enabledBorder: OutlineInputBorder(
                borderSide: BorderSide(
                  color: _color,
                ),
              ),
              focusedBorder: OutlineInputBorder(
                borderSide: BorderSide(color: _color),
              ),
              labelStyle: TextStyle(color: _color),
              suffixIcon: InkWell(
                borderRadius: BorderRadius.circular(50),
                child: Icon(
                  Icons.search,
                  color: _color,
                ),
                onTap: () {
                  this.widget.search(_searchController.text);
                },
              ),
              suffixStyle: TextStyle(color: _color),
            ),
          ),
        ),
      ),
    );
  }
}
